@@ -722,15 +722,6 @@ pub(crate) fn lex_tokens(syntax: Syntax, s: &'static str) -> Vec<Token> {
     .unwrap()
 }
 
-#[cfg(test)]
-pub(crate) fn lex_tokens_with_target(
-    syntax: Syntax,
-    target: EsVersion,
-    s: &'static str,
-) -> Vec<Token> {
-    with_lexer(syntax, target, s, |l| Ok(l.map(|ts| ts.token).collect())).unwrap()
-}
-
 /// Returns `(tokens, recovered_errors)`. `(tokens)` may contain an error token
 /// if the lexer fails to recover from it.
 #[cfg(test)]
